@@ -18,9 +18,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents German language.
+"""This module represents the German language.
 
-For more information, see U{http://en.wikipedia.org/wiki/German_language}
+.. seealso:: http://en.wikipedia.org/wiki/German_language
 """
 
 from translate.lang import common
