@@ -16,12 +16,11 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with translate; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents Hebrew language.
+"""This module represents the Hebrew language.
 
-For more information, see U{http://en.wikipedia.org/wiki/Hebrew_language}
+.. seealso:: http://en.wikipedia.org/wiki/Hebrew_language
 """
 
 from translate.lang import common
