@@ -16,8 +16,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with translate; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
 """
@@ -27,12 +26,12 @@ Xapian v1.0 or higher is supported.
 
 If you are interested in writing an interface for Xapian 0.x, then
 you should checkout the following::
+
     svn export -r 7235 https://translate.svn.sourceforge.net/svnroot/translate/src/branches/translate-search-indexer-generic-merging/translate/search/indexer/
+
 It is not completely working, but it should give you a good start.
 """
 
-__revision__ = "$Id: XapianIndexer.py 17248 2011-01-31 16:35:12Z friedelwolff $"
-
 # xapian module versions before 1.0.13 hangs apache under mod_python
 import sys
 import re
@@ -72,28 +71,29 @@ _MAX_TERM_LENGTH = 128
 
 
 class XapianDatabase(CommonIndexer.CommonDatabase):
-    """interface to the xapian (http://xapian.org) indexer
-    """
+    """Interface to the `Xapian indexer <http://xapian.org>`_."""
 
     QUERY_TYPE = xapian.Query
     INDEX_DIRECTORY_NAME = "xapian"
 
     def __init__(self, basedir, analyzer=None, create_allowed=True):
-        """initialize or open a xapian database
+        """Initialize or open a Xapian database.
 
-        @raise ValueError: the given location exists, but the database type
+        :raise ValueError: the given location exists, but the database type
                 is incompatible (e.g. created by a different indexing engine)
-        @raise OSError: the database failed to initialize
+        :raise OSError: the database failed to initialize
 
-        @param basedir: the parent directory of the database
-        @type basedir: str
-        @param analyzer: bitwise combination of possible analyzer flags
-            to be used as the default analyzer for this database. Leave it empty
-            to use the system default analyzer (self.ANALYZER_DEFAULT).
-            see self.ANALYZER_TOKENIZE, self.ANALYZER_PARTIAL, ...
-        @type analyzer: int
-        @param create_allowed: create the database, if necessary; default: True
-        @type create_allowed: bool
+        :param basedir: the parent directory of the database
+        :type basedir: str
+        :param analyzer: Bitwise combination of possible analyzer flags
+                         to be used as the default analyzer for this
+                         database. Leave it empty to use the system default
+                         analyzer (self.ANALYZER_DEFAULT).
+
+                         See self.ANALYZER_TOKENIZE, self.ANALYZER_PARTIAL, ...
+        :type analyzer: int
+        :param create_allowed: create the database, if necessary; default: True
+        :type create_allowed: bool
         """
         # call the __init__ function of our parent
         super(XapianDatabase, self).__init__(basedir, analyzer=analyzer,
@@ -137,8 +137,8 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
     def flush(self, optimize=False):
         """force to write the current changes to disk immediately
 
-        @param optimize: ignored for xapian
-        @type optimize: bool
+        :param optimize: ignored for xapian
+        :type optimize: bool
         """
         # write changes to disk (only if database is read-write)
         if self._writer_is_open():
@@ -157,10 +157,10 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
 
         basically this function should just create a copy of the original
 
-        @param query: the original query object
-        @type query: xapian.Query
-        @return: the resulting query object
-        @rtype: xapian.Query
+        :param query: the original query object
+        :type query: xapian.Query
+        :return: the resulting query object
+        :rtype: xapian.Query
         """
         # create a copy of the original query
         return xapian.Query(query)
@@ -172,20 +172,23 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         basically this function parses the string and returns the resulting
         query
 
-        @param text: the query string
-        @type text: str
-        @param require_all: boolean operator
-            (True -> AND (default) / False -> OR)
-        @type require_all: bool
-        @param analyzer: Define query options (partial matching, exact matching,
-            tokenizing, ...) as bitwise combinations of
-            CommonIndexer.ANALYZER_???.
-            This can override previously defined field analyzer settings.
-            If analyzer is None (default), then the configured analyzer for the
-            field is used.
-        @type analyzer: int
-        @return: resulting query object
-        @rtype: xapian.Query
+        :param text: the query string
+        :type text: str
+        :param require_all: boolean operator
+                            (True -> AND (default) / False -> OR)
+        :type require_all: bool
+        :param analyzer: Define query options (partial matching, exact matching,
+                         tokenizing, ...) as bitwise combinations of
+                         *CommonIndexer.ANALYZER_???*.
+
+                         This can override previously defined field
+                         analyzer settings.
+
+                         If analyzer is None (default), then the configured
+                         analyzer for the field is used.
+        :type analyzer: int
+        :return: resulting query object
+        :rtype: xapian.Query
         """
         qp = xapian.QueryParser()
         qp.set_database(self.reader)
@@ -211,19 +214,22 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
 
         this functions creates a field->value query
 
-        @param field: the fieldname to be used
-        @type field: str
-        @param value: the wanted value of the field
-        @type value: str
-        @param analyzer: Define query options (partial matching, exact matching,
-            tokenizing, ...) as bitwise combinations of
-            CommonIndexer.ANALYZER_???.
-            This can override previously defined field analyzer settings.
-            If analyzer is None (default), then the configured analyzer for the
-            field is used.
-        @type analyzer: int
-        @return: the resulting query object
-        @rtype: xapian.Query
+        :param field: the fieldname to be used
+        :type field: str
+        :param value: the wanted value of the field
+        :type value: str
+        :param analyzer: Define query options (partial matching, exact
+                         matching, tokenizing, ...) as bitwise combinations of
+                         *CommonIndexer.ANALYZER_???*.
+
+                         This can override previously defined field
+                         analyzer settings.
+
+                         If analyzer is None (default), then the configured
+                         analyzer for the field is used.
+        :type analyzer: int
+        :return: the resulting query object
+        :rtype: xapian.Query
         """
         if analyzer is None:
             analyzer = self.analyzer
@@ -245,13 +251,13 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
     def _create_query_combined(self, queries, require_all=True):
         """generate a combined query
 
-        @param queries: list of the original queries
-        @type queries: list of xapian.Query
-        @param require_all: boolean operator
-            (True -> AND (default) / False -> OR)
-        @type require_all: bool
-        @return: the resulting combined query object
-        @rtype: xapian.Query
+        :param queries: list of the original queries
+        :type queries: list of xapian.Query
+        :param require_all: boolean operator
+                            (True -> AND (default) / False -> OR)
+        :type require_all: bool
+        :return: the resulting combined query object
+        :rtype: xapian.Query
         """
         if require_all:
             query_op = xapian.Query.OP_AND
@@ -262,20 +268,20 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
     def _create_empty_document(self):
         """create an empty document to be filled and added to the index later
 
-        @return: the new document object
-        @rtype: xapian.Document
+        :return: the new document object
+        :rtype: xapian.Document
         """
         return xapian.Document()
 
     def _add_plain_term(self, document, term, tokenize=True):
         """add a term to a document
 
-        @param document: the document to be changed
-        @type document: xapian.Document
-        @param term: a single term to be added
-        @type term: str
-        @param tokenize: should the term be tokenized automatically
-        @type tokenize: bool
+        :param document: the document to be changed
+        :type document: xapian.Document
+        :param term: a single term to be added
+        :type term: str
+        :param tokenize: should the term be tokenized automatically
+        :type tokenize: bool
         """
         if tokenize:
             term_gen = xapian.TermGenerator()
@@ -287,14 +293,14 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
     def _add_field_term(self, document, field, term, tokenize=True):
         """add a field term to a document
 
-        @param document: the document to be changed
-        @type document: xapian.Document
-        @param field: name of the field
-        @type field: str
-        @param term: term to be associated to the field
-        @type term: str
-        @param tokenize: should the term be tokenized automatically
-        @type tokenize: bool
+        :param document: the document to be changed
+        :type document: xapian.Document
+        :param field: name of the field
+        :type field: str
+        :param term: term to be associated to the field
+        :type term: str
+        :param tokenize: should the term be tokenized automatically
+        :type tokenize: bool
         """
         if tokenize:
             term_gen = xapian.TermGenerator()
@@ -307,15 +313,15 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
     def _add_document_to_index(self, document):
         """add a prepared document to the index database
 
-        @param document: the document to be added
-        @type document: xapian.Document
+        :param document: the document to be added
+        :type document: xapian.Document
         """
         # open the database for writing
         self._writer_open()
         self.writer.add_document(document)
 
     def begin_transaction(self):
-        """begin a transaction
+        """Begin a transaction.
 
         Xapian supports transactions to group multiple database modifications.
         This avoids intermediate flushing and therefore increases performance.
@@ -332,30 +338,31 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         self._writer_close()
 
     def commit_transaction(self):
-        """submit the changes of an ongoing transaction
+        """Submit the changes of an ongoing transaction.
 
-        all changes since the last execution of 'begin_transaction' are written
+        All changes since the last execution of 'begin_transaction'
+        are written.
         """
         self.writer.commit_transaction()
         self._writer_close()
 
     def get_query_result(self, query):
-        """return an object containing the results of a query
+        """Return an object containing the results of a query.
 
-        @param query: a pre-compiled xapian query
-        @type query: xapian.Query
-        @return: an object that allows access to the results
-        @rtype: XapianIndexer.CommonEnquire
+        :param query: a pre-compiled xapian query
+        :type query: xapian.Query
+        :return: an object that allows access to the results
+        :rtype: XapianIndexer.CommonEnquire
         """
         enquire = xapian.Enquire(self.reader)
         enquire.set_query(query)
         return XapianEnquire(enquire)
 
     def delete_document_by_id(self, docid):
-        """delete a specified document
+        """Delete a specified document.
 
-        @param docid: the document ID to be deleted
-        @type docid: int
+        :param docid: the document ID to be deleted
+        :type docid: int
         """
         # open the database for writing
         self._writer_open()
@@ -366,35 +373,41 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
             return False
 
     def search(self, query, fieldnames):
-        """return a list of the contents of specified fields for all matches of
-        a query
+        """Return a list of the contents of specified fields for all matches
+        of a query.
 
-        @param query: the query to be issued
-        @type query: xapian.Query
-        @param fieldnames: the name(s) of a field of the document content
-        @type fieldnames: string | list of strings
-        @return: a list of dicts containing the specified field(s)
-        @rtype: list of dicts
+        :param query: the query to be issued
+        :type query: xapian.Query
+        :param fieldnames: the name(s) of a field of the document content
+        :type fieldnames: string | list of strings
+        :return: a list of dicts containing the specified field(s)
+        :rtype: list of dicts
         """
         result = []
         if isinstance(fieldnames, basestring):
             fieldnames = [fieldnames]
         try:
-            self._walk_matches(query, _extract_fieldvalues, (result, fieldnames))
+            self._walk_matches(query, _extract_fieldvalues,
+                               (result, fieldnames))
         except xapian.DatabaseModifiedError:
             self._index_refresh()
-            self._walk_matches(query, _extract_fieldvalues, (result, fieldnames))
+            self._walk_matches(query, _extract_fieldvalues,
+                               (result, fieldnames))
         return result
 
     def _delete_stale_lock(self):
         if not self._writer_is_open():
             lockfile = os.path.join(self.location, 'flintlock')
-            if os.path.exists(lockfile) and (time.time() - os.path.getmtime(lockfile)) / 60 > 15:
-                logging.warning("stale lock found in %s, removing.", self.location)
+            if (os.path.exists(lockfile) and
+                (time.time() - os.path.getmtime(lockfile)) / 60 > 15):
+                logging.warning("Stale lock found in %s, removing.",
+                                self.location)
                 os.remove(lockfile)
 
     def _writer_open(self):
-        """open write access for the indexing database and acquire an exclusive lock"""
+        """Open write access for the indexing database and acquire an
+        exclusive lock.
+        """
         if not self._writer_is_open():
             self._delete_stale_lock()
             try:
@@ -433,15 +446,16 @@ class XapianEnquire(CommonIndexer.CommonEnquire):
     """
 
     def get_matches(self, start, number):
-        """return a specified number of qualified matches of a previous query
+        """Return a specified number of qualified matches of a previous query.
 
-        @param start: index of the first match to return (starting from zero)
-        @type start: int
-        @param number: the number of matching entries to return
-        @type number: int
-        @return: a set of matching entries and some statistics
-        @rtype: tuple of (returned number, available number, matches)
+        :param start: index of the first match to return (starting from zero)
+        :type start: int
+        :param number: the number of matching entries to return
+        :type number: int
+        :return: a set of matching entries and some statistics
+        :rtype: tuple of (returned number, available number, matches)
                 "matches" is a dictionary of::
+
                     ["rank", "percent", "document", "docid"]
         """
         matches = self.enquire.get_mset(start, number)
@@ -460,14 +474,14 @@ def _truncate_term_length(term, taken=0):
     """truncate the length of a term string length to the maximum allowed
     for xapian terms
 
-    @param term: the value of the term, that should be truncated
-    @type term: str
-    @param taken: since a term consists of the name of the term and its
+    :param term: the value of the term, that should be truncated
+    :type term: str
+    :param taken: since a term consists of the name of the term and its
         actual value, this additional parameter can be used to reduce the
         maximum count of possible characters
-    @type taken: int
-    @return: the truncated string
-    @rtype: str
+    :type taken: int
+    :return: the truncated string
+    :rtype: str
     """
     if len(term) > _MAX_TERM_LENGTH - taken:
         return term[0:_MAX_TERM_LENGTH - taken - 1]
@@ -476,16 +490,17 @@ def _truncate_term_length(term, taken=0):
 
 
 def _extract_fieldvalues(match, (result, fieldnames)):
-    """add a dict of field values to a list
+    """Add a dict of field values to a list.
 
-    usually this function should be used together with '_walk_matches'
-    for traversing a list of matches
-    @param match: a single match object
-    @type match: xapian.MSet
-    @param result: the resulting dict will be added to this list
-    @type result: list of dict
-    @param fieldnames: the names of the fields to be added to the dict
-    @type fieldnames: list of str
+    Usually this function should be used together with :func:`_walk_matches`
+    for traversing a list of matches.
+
+    :param match: a single match object
+    :type match: xapian.MSet
+    :param result: the resulting dict will be added to this list
+    :type result: list of dict
+    :param fieldnames: the names of the fields to be added to the dict
+    :type fieldnames: list of str
     """
     # prepare empty dict
     item_fields = {}
