@@ -16,8 +16,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with translate; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 """Classes that hold units of .po files (pounit) or entire files (pofile).
 
@@ -55,8 +54,12 @@ class po_message(Structure):
     _fields_ = []
 
 # Function prototypes
-xerror_prototype = CFUNCTYPE(None, c_int, POINTER(po_message), STRING, c_uint, c_uint, c_int, STRING)
-xerror2_prototype = CFUNCTYPE(None, c_int, POINTER(po_message), STRING, c_uint, c_uint, c_int, STRING, POINTER(po_message), STRING, c_uint, c_uint, c_int, STRING)
+xerror_prototype = CFUNCTYPE(None, c_int, POINTER(po_message), STRING, c_uint,
+                             c_uint, c_int, STRING)
+xerror2_prototype = CFUNCTYPE(None, c_int, POINTER(po_message), STRING,
+                              c_uint, c_uint, c_int, STRING,
+                              POINTER(po_message), STRING, c_uint, c_uint,
+                              c_int, STRING)
 
 
 # Structures (error handler)
@@ -75,13 +78,16 @@ class po_error_handler(Structure):
 
 
 # Callback functions for po_xerror_handler
-def xerror_cb(severity, message, filename, lineno, column, multilint_p, message_text):
+def xerror_cb(severity, message, filename, lineno, column, multilint_p,
+              message_text):
     print >> sys.stderr, "xerror_cb", severity, message, filename, lineno, column, multilint_p, message_text
     if severity >= 1:
         raise ValueError(message_text)
 
 
-def xerror2_cb(severity, message1, filename1, lineno1, column1, multiline_p1, message_text1, message2, filename2, lineno2, column2, multiline_p2, message_text2):
+def xerror2_cb(severity, message1, filename1, lineno1, column1, multiline_p1,
+               message_text1, message2, filename2, lineno2, column2,
+               multiline_p2, message_text2):
     print >> sys.stderr, "xerror2_cb", severity, message1, filename1, lineno1, column1, multiline_p1, message_text1, message2, filename2, lineno2, column2, multiline_p2, message_text2
     if severity >= 1:
         raise ValueError(message_text1)
@@ -165,8 +171,8 @@ def unquotefrompo(postr):
 def get_libgettextpo_version():
     """Returns the libgettextpo version
 
-       @rtype: three-value tuple
-       @return: libgettextpo version in the following format::
+       :rtype: three-value tuple
+       :return: libgettextpo version in the following format::
            (major version, minor version, subminor version)
     """
     libversion = c_long.in_dll(gpo, 'libgettextpo_version')
@@ -466,8 +472,8 @@ class pounit(pocommon.pounit):
     def _extract_msgidcomments(self, text=None):
         """Extract KDE style msgid comments from the unit.
 
-        @rtype: String
-        @return: Returns the extracted msgidcomments found in this unit's msgid.
+        :rtype: String
+        :return: Returns the extracted msgidcomments found in this unit's msgid.
         """
         if not text:
             text = (gpo.po_message_msgid(self._gpo_message) or "").decode(self._encoding)
@@ -490,12 +496,12 @@ class pounit(pocommon.pounit):
         i = 0
         location = gpo.po_message_filepos(self._gpo_message, i)
         while location:
-            locname = gpo.po_filepos_file(location)
+            locname = gpo.po_filepos_file(location).decode(self._encoding)
             locline = gpo.po_filepos_start_line(location)
             if locline == -1:
                 locstring = locname
             else:
-                locstring = locname + ":" + str(locline)
+                locstring = locname + u":" + unicode(locline)
             locations.append(pocommon.unquote_plus(locstring))
             i += 1
             location = gpo.po_message_filepos(self._gpo_message, i)
@@ -505,10 +511,11 @@ class pounit(pocommon.pounit):
         if location.find(" ") != -1:
             location = pocommon.quote_plus(location)
         parts = location.split(":")
-        file = parts[0]
-        if len(parts) == 2:
+        if len(parts) == 2 and parts[1].isdigit():
+            file = parts[0]
             line = int(parts[1] or "0")
         else:
+            file = location
             line = -1
         gpo.po_message_add_filepos(self._gpo_message, file, line)
 
@@ -522,7 +529,7 @@ class pounit(pocommon.pounit):
 
     def setcontext(self, context):
         context = data.forceunicode(context)
-        gpo.po_message_set_msgctxt(self._gpo_message, context)
+        gpo.po_message_set_msgctxt(self._gpo_message, context.encode(self._encoding))
 
     def buildfromunit(cls, unit, encoding=None):
         """Build a native unit from a foreign unit, preserving as much
@@ -536,7 +543,7 @@ class pounit(pocommon.pounit):
             newunit.msgidcomment = unit._extract_msgidcomments()
             context = unit.getcontext()
             if not newunit.msgidcomment and context:
-                gpo.po_message_set_msgctxt(newunit._gpo_message, context)
+                newunit.setcontext(context)
 
             locations = unit.getlocations()
             if locations:
@@ -621,16 +628,16 @@ class pofile(pocommon.pofile):
                 elif duplicatestyle == "msgctxt":
                     origpo = id_dict[id]
                     if origpo not in markedpos:
-                        gpo.po_message_set_msgctxt(origpo._gpo_message, " ".join(origpo.getlocations()))
+                        origpo.setcontext(" ".join(origpo.getlocations()))
                         markedpos.append(thepo)
-                    gpo.po_message_set_msgctxt(thepo._gpo_message, " ".join(thepo.getlocations()))
+                    thepo.setcontext(" ".join(thepo.getlocations()))
                     uniqueunits.append(thepo)
             else:
                 if not id:
                     if duplicatestyle == "merge":
                         addcomment(thepo)
                     else:
-                        gpo.po_message_set_msgctxt(thepo._gpo_message, " ".join(thepo.getlocations()))
+                        thepo.setcontext(" ".join(thepo.getlocations()))
                 id_dict[id] = thepo
                 uniqueunits.append(thepo)
         new_gpo_memory_file = gpo.po_file_create()
