@@ -18,8 +18,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""classes that hold units of .po files (pounit) or entire files (pofile)
-gettext-style .po (or .pot) files are used in translations for KDE et al (see kbabel)"""
+"""Classes that hold units of Gettext .po files (pounit) or entire
+files (pofile).
+"""
 
 from __future__ import generators
 import copy
@@ -45,7 +46,7 @@ po_escape_map = dict([(value, key) for (key, value) in po_unescape_map.items()])
 def escapeforpo(line):
     """Escapes a line for po format. assumes no \n occurs in the line.
 
-    @param line: unescaped text
+    :param line: unescaped text
     """
     special_locations = []
     for special_key in po_escape_map:
@@ -83,7 +84,8 @@ def wrapline(line):
 
 
 def quoteforpo(text):
-    """quotes the given text for a PO file, returning quoted and escaped lines"""
+    """Quotes the given text for a PO file, returning quoted and
+    escaped lines"""
     polines = []
     if text is None:
         return polines
@@ -97,8 +99,7 @@ def quoteforpo(text):
             if len(lns) > 0:
                 for ln in lns[:-1]:
                     polines.extend(['"' + escapeforpo(ln) + '"'])
-                if lns[-1]:
-                    polines.extend(['"' + escapeforpo(lns[-1]) + '\\n"'])
+                polines.extend(['"' + escapeforpo(lns[-1]) + '\\n"'])
             else:
                 polines.extend(['"\\n"'])
     if lines[-1]:
@@ -109,14 +110,49 @@ def quoteforpo(text):
 def extractpoline(line):
     """Remove quote and unescape line from po file.
 
-    @param line: a quoted line from a po file (msgid or msgstr)
+    :param line: a quoted line from a po file (msgid or msgstr)
+
+    .. deprecated:: 1.10
     """
     extracted = quote.extractwithoutquotes(line, '"', '"', '\\', includeescapes=unescapehandler)[0]
     return extracted
 
 
+def unescape(line):
+    """Unescape the given line.
+
+    Quotes on either side should already have been removed.
+    """
+    escape_places = quote.find_all(line, u"\\")
+    if not escape_places:
+        return line
+
+    # filter escaped escapes
+    true_escape = False
+    true_escape_places = []
+    for escape_pos in escape_places:
+        if escape_pos - 1 in escape_places:
+            true_escape = not true_escape
+        else:
+            true_escape = True
+        if true_escape:
+            true_escape_places.append(escape_pos)
+
+    extracted = u""
+    lastpos = 0
+    for pos in true_escape_places:
+        # everything leading up to the escape
+        extracted += line[lastpos:pos]
+        # the escaped sequence (consuming 2 characters)
+        extracted += unescapehandler(line[pos:pos+2])
+        lastpos = pos+2
+
+    extracted += line[lastpos:]
+    return extracted
+
+
 def unquotefrompo(postr):
-    return "".join([extractpoline(line) for line in postr])
+    return u"".join([unescape(line[1:-1]) for line in postr])
 
 
 def is_null(lst):
@@ -183,13 +219,11 @@ class pounit(pocommon.pounit):
     allcomments = property(_get_all_comments)
 
     def _get_source_vars(self, msgid, msgid_plural):
-        multi = multistring(unquotefrompo(msgid), self._encoding)
+        singular = unquotefrompo(msgid)
         if self.hasplural():
             pluralform = unquotefrompo(msgid_plural)
-            if isinstance(pluralform, str):
-                pluralform = pluralform.decode(self._encoding)
-            multi.strings.append(pluralform)
-        return multi
+            return multistring([singular, pluralform], self._encoding)
+        return singular
 
     def _set_source_vars(self, source):
         msgid = None
@@ -216,7 +250,7 @@ class pounit(pocommon.pounit):
     def setsource(self, source):
         """Sets the msgid to the given (unescaped) value.
 
-        @param source: an unescaped source string.
+        :param source: an unescaped source string.
         """
         self._rich_source = None
         self.msgid, self.msgid_plural = self._set_source_vars(source)
@@ -229,7 +263,7 @@ class pounit(pocommon.pounit):
     def _set_prev_source(self, source):
         """Sets the msgid to the given (unescaped) value.
 
-        @param source: an unescaped source string.
+        :param source: an unescaped source string.
         """
         self.prev_msgid, self.prev_msgid_plural = self._set_source_vars(source)
     prev_source = property(_get_prev_source, _set_prev_source)
@@ -237,10 +271,9 @@ class pounit(pocommon.pounit):
     def gettarget(self):
         """Returns the unescaped msgstr"""
         if isinstance(self.msgstr, dict):
-            multi = multistring(map(unquotefrompo, self.msgstr.values()), self._encoding)
+            return multistring(map(unquotefrompo, self.msgstr.values()), self._encoding)
         else:
-            multi = multistring(unquotefrompo(self.msgstr), self._encoding)
-        return multi
+            return unquotefrompo(self.msgstr)
 
     def settarget(self, target):
         """Sets the msgstr to the given (unescaped) value"""
@@ -285,7 +318,10 @@ class pounit(pocommon.pounit):
         return []
 
     def getnotes(self, origin=None):
-        """Return comments based on origin value (programmer, developer, source code and translator)"""
+        """Return comments based on origin value.
+
+        :param origin: programmer, developer, source code, translator or None
+        """
         if origin == None:
             comments = u"".join([comment[2:] for comment in self.othercomments])
             comments += u"".join([comment[3:] for comment in self.automaticcomments])
@@ -299,7 +335,10 @@ class pounit(pocommon.pounit):
         return comments[:-1]
 
     def addnote(self, text, origin=None, position="append"):
-        """This is modeled on the XLIFF method. See xliff.py::xliffunit.addnote"""
+        """This is modeled on the XLIFF method.
+
+        See :meth:`translate.storage.xliff.xliffunit.addnote`
+        """
         # ignore empty strings and strings without non-space characters
         if not (text and text.strip()):
             return
@@ -418,8 +457,9 @@ class pounit(pocommon.pounit):
             mergelists(self.othercomments, otherpo.othercomments)
             mergelists(self.typecomments, otherpo.typecomments)
             if not authoritative:
-                # We don't bring across otherpo.automaticcomments as we consider ourself
-                # to be the the authority.  Same applies to otherpo.msgidcomments
+                # We don't bring across otherpo.automaticcomments as we
+                # consider ourself to be the the authority.  Same applies
+                # to otherpo.msgidcomments
                 mergelists(self.automaticcomments, otherpo.automaticcomments)
                 mergelists(self.msgidcomments, otherpo.msgidcomments)
                 mergelists(self.sourcecomments, otherpo.sourcecomments, split=True)
@@ -459,11 +499,21 @@ class pounit(pocommon.pounit):
 
     def hastypecomment(self, typecomment):
         """Check whether the given type comment is present"""
-        # check for word boundaries properly by using a regular expression...
-        return sum(map(lambda tcline: len(re.findall("\\b%s\\b" % typecomment, tcline)), self.typecomments)) != 0
+        if not self.typecomments:
+            return False
+        for tc in self.typecomments:
+            # check for word boundaries properly by using a regular expression
+            if re.search("\\b%s\\b" % typecomment, tc):
+                return True
+        return False
 
     def hasmarkedcomment(self, commentmarker):
-        """Check whether the given comment marker is present as # (commentmarker) ..."""
+        """Check whether the given comment marker is present.
+
+        These should appear as::
+
+                # (commentmarker) ...
+        """
         commentmarker = "(%s)" % commentmarker
         for comment in self.othercomments:
             if comment.replace("#", "", 1).strip().startswith(commentmarker):
@@ -570,14 +620,15 @@ class pounit(pocommon.pounit):
         return partstr
 
     def _encodeifneccessary(self, output):
-        """encodes unicode strings and returns other strings unchanged"""
+        """Encodes unicode strings and returns other strings unchanged"""
         if isinstance(output, unicode):
             encoding = encodingToUse(getattr(self, "_encoding", "UTF-8"))
             return output.encode(encoding)
         return output
 
     def __str__(self):
-        """convert to a string. double check that unicode is handled somehow here"""
+        """Convert to a string. Double check that unicode is handled
+        somehow here"""
         output = self._getoutput()
         return self._encodeifneccessary(output)
 
@@ -611,8 +662,9 @@ class pounit(pocommon.pounit):
                 obsoletelines[index] = obsoleteline.replace('\n"', '\n#~ "')
             lines.extend(obsoletelines)
             return u"".join(lines)
-        # if there's no msgid don't do msgid and string, unless we're the header
-        # this will also discard any comments other than plain othercomments...
+        # if there's no msgid don't do msgid and string, unless we're the
+        # header this will also discard any comments other than plain
+        # othercomments...
         if is_null(self.msgid):
             if not (self.isheader() or self.getcontext() or self.sourcecomments):
                 return u"".join(lines)
@@ -646,10 +698,11 @@ class pounit(pocommon.pounit):
     def addlocation(self, location):
         """Add a location to sourcecomments in the PO unit
 
-        @param location: Text location e.g. 'file.c:23' does not include #:
-        @type location: String
+        :param location: Text location e.g. 'file.c:23' does not include #:
+        :type location: String
 
         """
+        location = data.forceunicode(location)
         if location.find(" ") != -1:
             location = pocommon.quote_plus(location)
         self.sourcecomments.append("#: %s\n" % location)
@@ -657,8 +710,9 @@ class pounit(pocommon.pounit):
     def _extract_msgidcomments(self, text=None):
         """Extract KDE style msgid comments from the unit.
 
-        @rtype: String
-        @return: Returns the extracted msgidcomments found in this unit's msgid.
+        :rtype: String
+        :return: Returns the extracted msgidcomments found in this
+                 unit's msgid.
         """
 
         if not text:
@@ -718,7 +772,8 @@ class pofile(pocommon.pofile):
 #            raise base.ParseError(e)
 
     def removeduplicates(self, duplicatestyle="merge"):
-        """Make sure each msgid is unique ; merge comments etc from duplicates into original"""
+        """Make sure each msgid is unique ; merge comments etc from
+        duplicates into original"""
         # TODO: can we handle consecutive calls to removeduplicates()? What
         # about files already containing msgctxt? - test
         id_dict = {}
@@ -744,7 +799,8 @@ class pofile(pocommon.pofile):
                         uniqueunits.append(thepo)
                 elif duplicatestyle == "msgctxt":
                     origpo = id_dict[id]
-                    if origpo not in markedpos:
+                    if origpo not in markedpos and id:
+                        # if it doesn't have an id, we already added msgctxt
                         origpo.msgctxt.append('"%s"' % escapeforpo(" ".join(origpo.getlocations())))
                         markedpos.append(thepo)
                     thepo.msgctxt.append('"%s"' % escapeforpo(" ".join(thepo.getlocations())))
@@ -760,7 +816,8 @@ class pofile(pocommon.pofile):
         self.units = uniqueunits
 
     def __str__(self):
-        """Convert to a string. double check that unicode is handled somehow here"""
+        """Convert to a string. Double check that unicode is handled somehow
+        here"""
         output = self._getoutput()
         if isinstance(output, unicode):
             try:
@@ -802,11 +859,13 @@ class pofile(pocommon.pofile):
         """decode any non-unicode strings in lines with self._encoding"""
         newlines = []
         for line in lines:
-            if isinstance(line, str) and self._encoding is not None and self._encoding.lower() != "charset":
+            if (isinstance(line, str) and self._encoding is not None and
+                self._encoding.lower() != "charset"):
                 try:
                     line = line.decode(self._encoding)
                 except UnicodeError, e:
-                    raise UnicodeError("Error decoding line with encoding %r: %s. Line is %r" % (self._encoding, e, line))
+                    raise UnicodeError("Error decoding line with encoding %r: %s. Line is %r" %
+                                       (self._encoding, e, line))
             newlines.append(line)
         return newlines
 
