@@ -21,9 +21,6 @@
 
 """Module to provide a cache of statistics in a database.
 
-@organization: Zuza Software Foundation
-@copyright: 2007 Zuza Software Foundation
-@license: U{GPL <http://www.fsf.org/licensing/licenses/gpl.html>}
 """
 
 try:
@@ -291,7 +288,8 @@ class StatsCache(object):
         def make_database(statsfile):
 
             def connect(cache):
-                cache.con = dbapi2.connect(statsfile)
+                # sqlite needs to get the name in utf-8 on all platforms
+                cache.con = dbapi2.connect(statsfile.encode('utf-8'))
                 cache.cur = cache.con.cursor()
 
             def clear_old_data(cache):
@@ -326,7 +324,8 @@ class StatsCache(object):
                     cachedir = os.path.join(userdir, ".translate_toolkit")
                 if not os.path.exists(cachedir):
                     os.mkdir(cachedir)
-                cls.defaultfile = os.path.realpath(os.path.join(cachedir, "stats.db"))
+                cachedir = cachedir.decode(sys.getfilesystemencoding())
+                cls.defaultfile = os.path.realpath(os.path.join(cachedir, u"stats.db"))
             statsfile = cls.defaultfile
         else:
             statsfile = os.path.realpath(statsfile)
@@ -466,9 +465,10 @@ class StatsCache(object):
         unconditionally."""
         self.cur.execute("""DELETE FROM files WHERE
             path=?;""", (realpath,))
-        self.cur.execute("""INSERT INTO files
+        self.cur.execute("""iNSERT INTO files
             (fileid, path, st_mtime, st_size, toolkitbuild) values (NULL, ?, ?, ?, ?);""",
             (realpath, mod_info[0], mod_info[1], toolkitversion.build))
+        # Unusual capitalisation intended. See bug 2073.
         fileid = self.cur.lastrowid
         self.cur.execute("""DELETE FROM units WHERE
             fileid=?""", (fileid,))
@@ -626,9 +626,10 @@ class StatsCache(object):
         configid = self._getstoredcheckerconfig(checker)
         if configid:
             return configid
-        self.cur.execute("""INSERT INTO checkerconfigs
+        self.cur.execute("""iNSERT INTO checkerconfigs
             (configid, config) values (NULL, ?);""",
             (str(checker.config.__dict__),))
+        # Unusual capitalisation intended. See bug 2073.
         return self.cur.lastrowid
 
     def filechecks(self, filename, checker, store=None):
@@ -642,10 +643,10 @@ class StatsCache(object):
         for value in values:
             if value[1] == -1:
                 continue
-            checkkey = 'check-' + value[0]      #value[0] is the error name
+            checkkey = 'check-' + value[0]      # value[0] is the error name
             if not checkkey in errors:
                 errors[checkkey] = []
-            errors[checkkey].append(value[1])   #value[1] is the unitindex
+            errors[checkkey].append(value[1])   # value[1] is the unitindex
 
         return errors
 
