@@ -16,8 +16,6 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with translate; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""translate.tools is part of the translate package
-It contains code to perform various operations (mostly on po files)"""
+"""Code to perform various operations, mostly on po files."""
