@@ -14,13 +14,12 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with translate; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""reads a set of .po or .pot files to produce a pootle-terminology.pot
+"""Create a terminology file by reading a set of .po or .pot files to produce a pootle-terminology.pot.
 
-See: http://translate.sourceforge.net/wiki/toolkit/poterminology for examples and
-usage instructions
+See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/poterminology.html
+for examples and usage instructions.
 """
 import os
 import re
@@ -89,7 +88,7 @@ class TerminologyExtractor(object):
         self.xmlelpat = re.compile(r"<(?:![[-]|[/?]?[A-Za-z_:])[^>]*>")
         # handles XML/HTML entities (&#32; &#x20; &amp; &my_entity;)
         self.xmlentpat = re.compile(r"&(?:#(?:[0-9]+|x[0-9a-f]+)|[a-z_:][\w.-:]*);",
-                               flags=re.UNICODE|re.IGNORECASE)
+                               flags=re.UNICODE | re.IGNORECASE)
 
         self.units = 0
         self.glossary = {}
@@ -121,7 +120,7 @@ class TerminologyExtractor(object):
                     else:
                         logging.warning("%s line %d - bad case mapping directive", (self.stopfile, line))
                 elif stoptype == '/':
-                    self.stoprelist.append(re.compile(stopline[1:-1]+'$'))
+                    self.stoprelist.append(re.compile(stopline[1:-1] + '$'))
                 else:
                     self.stopwords[stopline[1:-1]] = actions[stoptype]
         except KeyError, character:
@@ -292,7 +291,9 @@ class TerminologyExtractor(object):
             terms[term] = ((10 * numfiles) + numsources, termunit)
         return terms
 
-    def filter_terms(self, terms, nonstopmin=1, sortorders=["frequency", "dictionary", "length"]):
+    sortorders_default = ["frequency", "dictionary", "length"]
+
+    def filter_terms(self, terms, nonstopmin=1, sortorders=sortorders_default):
         """reduce subphrases from extracted terms"""
         # reduce subphrase
         termlist = terms.keys()
@@ -317,6 +318,8 @@ class TerminologyExtractor(object):
                     del terms[' '.join(words)]
         print >> sys.stderr, "%d terms after subphrase reduction" % len(terms.keys())
         termitems = terms.values()
+        if sortorders is None:
+            sortorders = self.sortorders_default
         while len(sortorders) > 0:
             order = sortorders.pop()
             if order == "frequency":
@@ -478,7 +481,7 @@ def main():
         action="store_true", help="make all terms lowercase")
 
     parser.add_option("", "--accelerator", dest="accelchars", default="",
-        metavar="ACCELERATORS", help="ignores the given accelerator characters when matching")
+        metavar="ACCELERATORS", help="ignore the given accelerator characters when matching")
 
     parser.add_option("-t", "--term-words", type="int", dest="termlength", default="3",
         help="generate terms of up to LENGTH words (default 3)", metavar="LENGTH")
@@ -493,10 +496,9 @@ def main():
     parser.add_option("", "--locs-needed", type="int", dest="locmin", default="2",
         help="omit terms appearing in less than MIN different original source files (default 2)", metavar="MIN")
 
-    sortorders_default = ["frequency", "dictionary", "length"]
     parser.add_option("", "--sort", dest="sortorders", action="append",
-        type="choice", choices=sortorders_default, metavar="ORDER", default=sortorders_default,
-        help="output sort order(s): %s (default is all orders in the above priority)" % ', '.join(sortorders_default))
+        type="choice", choices=TerminologyExtractor.sortorders_default, metavar="ORDER",
+        help="output sort order(s): %s (may repeat option, default is all in above order)" % ', '.join(TerminologyExtractor.sortorders_default))
 
     parser.add_option("", "--source-language", dest="sourcelanguage", default="en",
         help="the source language code (default 'en')", metavar="LANG")
